@@ -224,8 +224,8 @@ def cli(
                             _desc = process_description(
                                 group_description, user_language
                                 )
-                            description_text = _desc["group_description"]
-                            original_language = _mess[
+                            
+                            original_language = _desc[
                                 "original_language"
                             ]
                             translated_description = _desc["translated_text"]
@@ -423,7 +423,7 @@ def cli(
                         _desc = process_description(
                             group_description, user_language
                             )
-                        description_text = _desc["description_text"]
+
                         original_language = _desc[
                             "original_language"
                         ]
